/*
 *	    ____  ____  _____   ____________
 *	   / __ / __ /  _/ | / /_  __/ __
 *	  / /_/ / /_/ // //  |/ / / / / /_/ /
 *	 / ____/ _, _// // /|  / / / / _, _/
 *	/_/   /_/ |_/___/_/ |_/ /_/ /_/ |_|
 *
 */

/*
 *	Login to Formide API and store cookie
 */

var fs				= require('fs');
var request 		= require('request');
var argv 			= require('optimist').argv;
var prompt 			= require('prompt');
var FormideStore 	= require('./store.js').FormideStore;
var Task 			= require('./task.js').Task;

var FormideTask = function() {};
FormideTask.prototype = new Task();

FormideTask.prototype.get = function(formide, callback)
{
	this.cookieData = new FormideStore('cookies');

	if( formide.jar )
	{
		callback( formide.jar );
		return;
	}

	this.email = argv.email || argv.e || process.env.FORMIDE_EMAIL;
	this.password = argv.password || argv.p || process.env.FORMIDE_PASSWORD;

	if(!this.email && this.password)
	{
		return formide.fail('--email or -e command line flag, or FORMIDE_EMAIL environment variable required');
	}

	if(this.email && !this.password)
	{
    	return formide.fail('--password or -p command line flag, or FORMIDE_PASSWORD environment variable required');
  	}

  	if(!this.email && !this.password)
  	{
    	// did not include cmd line flags, check for existing cookies
		var jar = this.cookieData.get(formide.FORMIDE_API);

		if(jar && jar.length)
		{
			for(var i in jar)
			{
				var cookie = jar[i];
				if(cookie.key == "sessionid" && new Date(cookie.expires) > new Date())
				{
					formide.jar = jar;
					callback(jar);
					return;
        		}
      		}
    	}
  	}

  	this.run( formide, callback );
};

FormideTask.prototype.run = function( formide, callback )
{
	var self = this;

	if( !this.email && !this.password )
	{
		var schema = [
		{
			name: 'email',
			pattern: /^[A-z0-9!#$%&'*+\/=?\^_{|}~\-]+(?:\.[A-z0-9!#$%&'*+\/=?\^_{|}~\-]+)*@(?:[A-z0-9](?:[A-z0-9\-]*[A-z0-9])?\.)+[A-z0-9](?:[A-z0-9\-]*[A-z0-9])?$/,
			description: 'Email:'.yellow.bold,
			required: true
		},
		{
			name: 'password',
			description: 'Password:'.yellow.bold,
			hidden: true,
			required: true
		}];

		// prompt for log
		console.log('\nTo continue, please login to your Formide account.'.bold.green);
		console.log('Don\'t have one? Create a one at: '.bold + (formide.FORMIDE_API + '/auth/v1/register').bold + '\n');

		prompt.override = argv;
		prompt.message = '';
		prompt.delimiter = '';
		prompt.start();

		prompt.get(schema, function (err, result)
		{
			if(err)
			{
				return formide.fail('Error logging in: ' + err);
			}

			self.email = result.email;
			self.password = result.password;

			self.requestLogIn(formide, callback, true);
		});
	}
	else
	{
		self.requestLogIn(formide, callback, false);
	}
};

FormideTask.prototype.requestLogIn = function( formide, callback, saveCookies )
{
	var self = this;
	var transformedCookies = null;
	var jar = request.jar();

	request({
		method: 'POST',
		url: formide.FORMIDE_API + formide.API_AUTH + '/login',
		jar: jar,
		strictSSL: false,
		form: {
			email: self.email.toString().toLowerCase(),
			password: self.password,
			cli: true
		},
		proxy: process.env.PROXY || process.env.http_proxy || null
	},
	function( err, response, body )
	{
		if( err )
		{
			return formide.fail( 'Error logging in: ' + err );
		}

		if( response.statusCode != 200)
		{
			return formide.fail( 'Email or Password incorrect. Please visit '+ formide.FORMIDE_API.white +' for help.'.red );
		}

		if( saveCookies )
		{
			if( !self.cookieData )
			{
				self.cookieData = new FormideStore('cookies');
			}
			self.cookieData.set(formide.FORMIDE_API, jar.getCookies(formide.FORMIDE_API));
			self.cookieData.save();

			transformedCookies = self.cookieData.get(formide.FORMIDE_API);
		}
		else
		{
			try
			{
				var jsonString = JSON.stringify(jar.getCookies(formide.FORMIDE_API, null, 2));
				transformedCookies = JSON.parse(jsonString);
			}
			catch( e )
			{
				console.log('Invalid cookies from jar.getCookies'.red.bold);
			}
		}

		// save in memory
		formide.jar = transformedCookies;

		console.log('Logged in! :)'.green);

		if(callback)
		{
			callback(transformedCookies);
    	}
	});
}

exports.FormideTask = FormideTask;