/*
 *	    ____  ____  _____   ____________
 *	   / __ / __ /  _/ | / /_  __/ __
 *	  / /_/ / /_/ // //  |/ / / / / /_/ /
 *	 / ____/ _, _// // /|  / / / / _, _/
 *	/_/   /_/ |_/___/_/ |_/ /_/ /_/ |_|
 *
 */

/*
 *	Simple get/set storage to files
 */

var fs 		= require('fs');
var path 	= require('path');

var FormideStore = function(fileName)
{
	this.data = {};

	if (!fileName)
	{
		return this;
	}

	this.fileName = fileName;

	if (fileName.indexOf('.') < 0)
	{
		this.fileName += '.data';
	}

	this.homeDir = process.env.HOME || process.env.USERPROFILE || process.env.HOMEPATH;
	this.privateDir = path.join(this.homeDir, '.formide');

	if (!fs.existsSync(this.privateDir))
	{
		fs.mkdirSync(this.privateDir);
	}

	this.filePath = path.join(this.privateDir, this.fileName);

	try
	{
		this.data = JSON.parse(fs.readFileSync(this.filePath));
	}
	catch (e)
	{

	}

	return this;
};

FormideStore.prototype.get = function(k)
{
	if (k)
	{
		return this.data[k];
	}

	return this.data;
};

FormideStore.prototype.set = function(k, v)
{
	this.data[k] = v;
};

FormideStore.prototype.remove = function(k)
{
	delete this.data[k];
};

FormideStore.prototype.save = function()
{
	try
	{
		var dataStoredAsString = JSON.stringify(this.data, null, 2);
		fs.writeFileSync(this.filePath, dataStoredAsString);
		this.data = JSON.parse(dataStoredAsString);
	}
	catch( e )
	{
		console.error('Unable to save formide data:', this.filePath, e);
	}
};

exports.FormideStore = FormideStore;